# -*- coding: utf-8 -*-
# $Id: __init__.py 76587 2008-11-29 16:33:21Z glenfant $
"""Collage content types"""

from Products.Collage.content._collage import Collage
from Products.Collage.content._row import CollageRow
from Products.Collage.content._column import CollageColumn
from Products.Collage.content._alias import CollageAlias
